[gimp/gtk3-port: 1/226] Switch to version 3.0 in a lot of places and depend on GTK+ 3.2



commit a5d88fa072d67094594dfad9f4af4fbd98a0cf8d
Author: Michael Natterer <mitch gimp org>
Date:   Fri Oct 15 09:56:27 2010 +0200

    Switch to version 3.0 in a lot of places and depend on GTK+ 3.2
    
    and lots of other newer libraries.

 .gitignore                      |    6 ++--
 app/config/gimpconfig-dump.c    |   12 ++++----
 app/gui/gui.c                   |    6 ++--
 app/sanity.c                    |    4 +-
 configure.ac                    |   52 ++++++++++++++------------------------
 docs/.gitignore                 |    6 ++--
 docs/gimp.1.in                  |   10 +++---
 docs/gimprc.5.in                |    8 +++---
 etc/gimprc                      |    4 +-
 libgimpbase/gimpenv.c           |   32 ++++++++++++------------
 libgimpwidgets/gimp3migration.c |    5 +++
 libgimpwidgets/gimp3migration.h |    4 +++
 tools/.gitignore                |    4 +-
 tools/Makefile.am               |    8 +++---
 14 files changed, 78 insertions(+), 83 deletions(-)
---
diff --git a/.gitignore b/.gitignore
index f6c77ce..cb3d54f 100644
--- a/.gitignore
+++ b/.gitignore
@@ -25,10 +25,10 @@
 /cscope.files
 /cscope.out
 /depcomp
-/gimp-2.0.pc
+/gimp-3.0.pc
 /gimp-zip
-/gimpthumb-2.0.pc
-/gimpui-2.0.pc
+/gimpthumb-3.0.pc
+/gimpui-3.0.pc
 /gtk-doc.make
 /install-sh
 /intltool-extract
diff --git a/app/config/gimpconfig-dump.c b/app/config/gimpconfig-dump.c
index cd639de..dd9fe66 100644
--- a/app/config/gimpconfig-dump.c
+++ b/app/config/gimpconfig-dump.c
@@ -106,8 +106,8 @@ static const gchar system_gimprc_header[] =
 "documents the default values and shows what changes are possible.\n"
 "\n"
 "The variable ${gimp_dir} is set to the value of the environment "
-"variable GIMP2_DIRECTORY or, if that is not set, the compiled-in "
-"default value is used.  If GIMP2_DIRECTORY is not an absolute path, "
+"variable GIMP3_DIRECTORY or, if that is not set, the compiled-in "
+"default value is used.  If GIMP3_DIRECTORY is not an absolute path, "
 "it is interpreted relative to your home directory.";
 
 static void
@@ -210,21 +210,21 @@ static const gchar *man_page_path =
 ".TP\n"
 ".I gimp_dir\n"
 "The personal gimp directory which is set to the value of the environment\n"
-"variable GIMP2_DIRECTORY or to ~/@gimpdir  \n"
+"variable GIMP3_DIRECTORY or to ~/@gimpdir  \n"
 ".TP\n"
 ".I gimp_data_dir\n"
 "Base for paths to shareable data, which is set to the value of the\n"
-"environment variable GIMP2_DATADIR or to the compiled-in default value\n"
+"environment variable GIMP3_DATADIR or to the compiled-in default value\n"
 "@gimpdatadir  \n"
 ".TP\n"
 ".I gimp_plug_in_dir\n"
 "Base to paths for architecture-specific plugins and modules, which is set\n"
-"to the value of the environment variable GIMP2_PLUGINDIR or to the\n"
+"to the value of the environment variable GIMP3_PLUGINDIR or to the\n"
 "compiled-in default value @gimpplugindir  \n"
 ".TP\n"
 ".I gimp_sysconf_dir\n"
 "Path to configuration files, which is set to the value of the environment\n"
-"variable GIMP2_SYSCONFDIR or to the compiled-in default value \n"
+"variable GIMP3_SYSCONFDIR or to the compiled-in default value \n"
 "@gimpsysconfdir  \n"
 "\n";
 
diff --git a/app/gui/gui.c b/app/gui/gui.c
index b6825f5..0162cc5 100644
--- a/app/gui/gui.c
+++ b/app/gui/gui.c
@@ -252,9 +252,9 @@ gui_init (Gimp     *gimp,
 static gchar *
 gui_sanity_check (void)
 {
-#define GTK_REQUIRED_MAJOR 2
-#define GTK_REQUIRED_MINOR 24
-#define GTK_REQUIRED_MICRO 10
+#define GTK_REQUIRED_MAJOR 3
+#define GTK_REQUIRED_MINOR 4
+#define GTK_REQUIRED_MICRO 0
 
   const gchar *mismatch = gtk_check_version (GTK_REQUIRED_MAJOR,
                                              GTK_REQUIRED_MINOR,
diff --git a/app/sanity.c b/app/sanity.c
index 77ecc8c..9089134 100644
--- a/app/sanity.c
+++ b/app/sanity.c
@@ -320,8 +320,8 @@ static gchar *
 sanity_check_gdk_pixbuf (void)
 {
 #define GDK_PIXBUF_REQUIRED_MAJOR 2
-#define GDK_PIXBUF_REQUIRED_MINOR 24
-#define GDK_PIXBUF_REQUIRED_MICRO 1
+#define GDK_PIXBUF_REQUIRED_MINOR 26
+#define GDK_PIXBUF_REQUIRED_MICRO 0
 
   if (! sanity_check_version (gdk_pixbuf_major_version, GDK_PIXBUF_REQUIRED_MAJOR,
                               gdk_pixbuf_minor_version, GDK_PIXBUF_REQUIRED_MINOR,
diff --git a/configure.ac b/configure.ac
index cf329d8..e82d5f6 100644
--- a/configure.ac
+++ b/configure.ac
@@ -7,8 +7,8 @@ AC_PREREQ(2.54)
 #   GIMP_INTERFACE_AGE += 1;
 
 m4_define([gimp_major_version], [2])
-m4_define([gimp_minor_version], [9])
-m4_define([gimp_micro_version], [1])
+m4_define([gimp_minor_version], [99])
+m4_define([gimp_micro_version], [0])
 m4_define([gimp_real_version],
           [gimp_major_version.gimp_minor_version.gimp_micro_version])
 m4_define([gimp_version], [gimp_real_version])
@@ -17,20 +17,20 @@ m4_define([gimp_binary_age],
           [m4_eval(100 * gimp_minor_version + gimp_micro_version)])
 
 # For overriding the version string. Comment out if not needed.
-# m4_define([gimp_version], [2.9.1])
+# m4_define([gimp_version], [2.99.0])
 
 # This is the X.Y used in -lgimp-X.Y
-m4_define([gimp_api_version], [2.0])
+m4_define([gimp_api_version], [3.0])
 
 # Versions used for apps, plugins, tools, pkg-config files, and data,
 # as well as global and user prefs
-m4_define([gimp_app_version], [2.9])
-m4_define([gimp_plugin_version], [2.0])
-m4_define([gimp_tool_version], [2.0])
-m4_define([gimp_pkgconfig_version], [2.0])
-m4_define([gimp_data_version], [2.0])
-m4_define([gimp_sysconf_version], [2.0])
-m4_define([gimp_user_version], [2.9])
+m4_define([gimp_app_version], [2.99])
+m4_define([gimp_plugin_version], [3.0])
+m4_define([gimp_tool_version], [3.0])
+m4_define([gimp_pkgconfig_version], [3.0])
+m4_define([gimp_data_version], [3.0])
+m4_define([gimp_sysconf_version], [3.0])
+m4_define([gimp_user_version], [3.0])
 
 m4_define([gimp_unstable],
           m4_if(m4_eval(gimp_minor_version % 2), [1], [yes], [no]))
@@ -43,9 +43,9 @@ m4_define([gimp_full_name], [GNU Image Manipulation Program])
 m4_define([babl_required_version], [0.1.11])
 m4_define([gegl_required_version], [0.3.0])
 m4_define([glib_required_version], [2.36.0])
-m4_define([atk_required_version], [2.2.0])
-m4_define([gtk_required_version], [2.24.10])
-m4_define([gdk_pixbuf_required_version], [2.24.1])
+m4_define([atk_required_version], [2.4.0])
+m4_define([gtk_required_version], [3.4.0])
+m4_define([gdk_pixbuf_required_version], [2.26.0])
 m4_define([cairo_required_version], [1.12.2])
 m4_define([cairo_pdf_required_version], [1.12.2])
 m4_define([pangocairo_required_version], [1.29.4])
@@ -150,7 +150,7 @@ AC_SUBST(LT_CURRENT_MINUS_AGE)
 
 
 # gettext i18n support
-GETTEXT_PACKAGE=gimp20
+GETTEXT_PACKAGE=gimp30
 AC_SUBST(GETTEXT_PACKAGE)
 AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE, "$GETTEXT_PACKAGE",
                    [The prefix for our gettext translation domains.])
@@ -522,19 +522,9 @@ LIBS=$gimp_save_LIBS
 
 AC_PATH_XTRA
 
-AM_PATH_GTK_2_0(gtk_required_version, :,
+AM_PATH_GTK_3_0(gtk_required_version, :,
   AC_MSG_ERROR(Test for GTK+ failed. See the file 'INSTALL' for help.))
 
-# GTK+ 2.26.0 will never be released, we keep the check around anyway
-# because we will need it again after the switch to GTK+ 3.x
-AC_MSG_CHECKING([if GTK+ is version 2.26.0 or newer (bogus placeholder check)])
-if $PKG_CONFIG --atleast-version=2.26.0 gtk+-2.0; then
-  have_gtk_2_26=yes
-else
-  have_gtk_2_26=no
-fi
-AC_MSG_RESULT($have_gtk_2_26)
-
 PKG_CHECK_MODULES(GDK_PIXBUF, gdk-pixbuf-2.0 >= gdk_pixbuf_required_version)
 
 AC_PATH_PROG(GDK_PIXBUF_CSOURCE, gdk-pixbuf-csource, no)
@@ -1009,7 +999,7 @@ fi
 ################################
 
 # Check if building for GTK+-X11
-gdk_target=`$PKG_CONFIG --variable=target gtk+-2.0`
+gdk_target=`$PKG_CONFIG --variable=target gtk+-3.0`
 
 have_libxmu="no (building for $gdk_target)"
 
@@ -1435,7 +1425,7 @@ AC_ARG_WITH(webkit, [  --without-webkit        don't build the help-browser plug
 
 have_webkit=no
 if test "x$with_webkit" != xno; then
-  PKG_CHECK_MODULES(WEBKIT, webkit-1.0 >= webkit_required_version,
+  PKG_CHECK_MODULES(WEBKIT, webkitgtk-3.0 >= webkitgtk_required_version,
     WEB_PAGE='web-page$(EXEEXT)'
     have_webkit=yes,
     have_webkit="no (WebKit not found)")
@@ -2059,11 +2049,7 @@ if test "x$have_glib_2_39" != "xyes"; then
   CPPFLAGS="${CPPFLAGS} -DG_DISABLE_DEPRECATED"
 fi
 
-if test "x$have_gtk_2_26" != "xyes"; then
-  CPPFLAGS="${CPPFLAGS} -DGDK_DISABLE_DEPRECATED -DGTK_DISABLE_DEPRECATED"
-fi
-
-if test "x$have_gdk_pixbuf_2_31" != "xyes"; then
+if test "x$have_gdk_pixbuf_2_26" != "xyes"; then
   CPPFLAGS="${CPPFLAGS} -DGDK_PIXBUF_DISABLE_DEPRECATED"
 fi
 
diff --git a/docs/.gitignore b/docs/.gitignore
index 3292440..2945135 100644
--- a/docs/.gitignore
+++ b/docs/.gitignore
@@ -1,7 +1,7 @@
 /Makefile
 /Makefile.in
-/gimp-2.*.1
-/gimprc-2.*.5
-/gimptool-2.0.1
+/gimp-3.*.1
+/gimprc-3.*.5
+/gimptool-3.0.1
 /Wilber.xcf
 /Wilber_Construction_Kit.xcf
diff --git a/docs/gimp.1.in b/docs/gimp.1.in
index 64bb37a..85411be 100644
--- a/docs/gimp.1.in
+++ b/docs/gimp.1.in
@@ -151,24 +151,24 @@ GIMP respects a number of environment variables.
 .B DISPLAY
 to get the default host and display number.
 .TP 8
-.B GIMP2_DIRECTORY
+.B GIMP3_DIRECTORY
 to get the name of the personal GIMP directory. If unset @gimpdir@ is
 used.  If this is an absolute path, it is used as is.  If it is a
 relative path, it is taken to be a subdirectory of the home directory.
 .TP 8
-.B GIMP2_DATADIR
+.B GIMP3_DATADIR
 to get the base location for data files such as brushes and patterns.
 If unset @gimpdatadir@ is used.
 .TP 8
-.B GIMP2_LOCALEDIR
+.B GIMP3_LOCALEDIR
 to get the base location for translations. If unset @gimplocaledir@
 is used.
 .TP 8
-.B GIMP2_PLUGINDIR
+.B GIMP3_PLUGINDIR
 to get the base location for plug-ins and modules. If unset
 @gimpplugindir@ is used.
 .TP 8
-.B GIMP2_SYSCONFDIR
+.B GIMP3_SYSCONFDIR
 to get the location of configuration files. If unset @gimpsysconfdir@
 is used.
 
diff --git a/docs/gimprc.5.in b/docs/gimprc.5.in
index c31afac..64da6ee 100644
--- a/docs/gimprc.5.in
+++ b/docs/gimprc.5.in
@@ -925,21 +925,21 @@ There are a few variables that are pre-defined:
 .TP
 .I gimp_dir
 The personal gimp directory which is set to the value of the environment
-variable GIMP2_DIRECTORY or to ~/@gimpdir  
+variable GIMP3_DIRECTORY or to ~/@gimpdir  
 .TP
 .I gimp_data_dir
 Base for paths to shareable data, which is set to the value of the
-environment variable GIMP2_DATADIR or to the compiled-in default value
+environment variable GIMP3_DATADIR or to the compiled-in default value
 @gimpdatadir  
 .TP
 .I gimp_plug_in_dir
 Base to paths for architecture-specific plugins and modules, which is set
-to the value of the environment variable GIMP2_PLUGINDIR or to the
+to the value of the environment variable GIMP3_PLUGINDIR or to the
 compiled-in default value @gimpplugindir  
 .TP
 .I gimp_sysconf_dir
 Path to configuration files, which is set to the value of the environment
-variable GIMP2_SYSCONFDIR or to the compiled-in default value 
+variable GIMP3_SYSCONFDIR or to the compiled-in default value 
 @gimpsysconfdir  
 
 .SH FILES
diff --git a/etc/gimprc b/etc/gimprc
index 18dab53..fa7cd99 100644
--- a/etc/gimprc
+++ b/etc/gimprc
@@ -8,8 +8,8 @@
 # documents the default values and shows what changes are possible.
 # 
 # The variable ${gimp_dir} is set to the value of the environment variable
-# GIMP2_DIRECTORY or, if that is not set, the compiled-in default value is
-# used.  If GIMP2_DIRECTORY is not an absolute path, it is interpreted
+# GIMP3_DIRECTORY or, if that is not set, the compiled-in default value is
+# used.  If GIMP3_DIRECTORY is not an absolute path, it is interpreted
 # relative to your home directory.
 
 # Sets the folder for temporary storage. Files will appear here during the
diff --git a/libgimpwidgets/gimp3migration.c b/libgimpwidgets/gimp3migration.c
index 44eca9a..7764161 100644
--- a/libgimpwidgets/gimp3migration.c
+++ b/libgimpwidgets/gimp3migration.c
@@ -30,6 +30,8 @@
 #include "gimp3migration.h"
 
 
+#if 0
+
 GtkWidget *
 gtk_box_new (GtkOrientation  orientation,
              gint            spacing)
@@ -87,6 +89,9 @@ gtk_separator_new (GtkOrientation  orientation)
     return gtk_vseparator_new ();
 }
 
+#endif /* if 0 */
+
+
 #if ! GTK_CHECK_VERSION (3, 3, 0)
 
 gboolean
diff --git a/libgimpwidgets/gimp3migration.h b/libgimpwidgets/gimp3migration.h
index daf338c..1bb709c 100644
--- a/libgimpwidgets/gimp3migration.h
+++ b/libgimpwidgets/gimp3migration.h
@@ -33,6 +33,8 @@
  * along. This file will be removed in GIMP 3.
  */
 
+#if 0
+
 GtkWidget * gtk_box_new        (GtkOrientation  orientation,
                                 gint            spacing);
 GtkWidget * gtk_button_box_new (GtkOrientation  orientation);
@@ -43,6 +45,8 @@ GtkWidget * gtk_scrollbar_new  (GtkOrientation  orientation,
                                 GtkAdjustment  *adjustment);
 GtkWidget * gtk_separator_new  (GtkOrientation  orientation);
 
+#endif
+
 
 /* These functions are even more evil. They exist only since GTK+ 3.3
  * and need to be taken care of carefully when building against GTK+
diff --git a/tools/.gitignore b/tools/.gitignore
index 4c7fef5..9ca4384 100644
--- a/tools/.gitignore
+++ b/tools/.gitignore
@@ -3,7 +3,7 @@
 /.deps
 /.libs
 /kernelgen
-/gimptool-2.0
-/gimptool-2.0.exe
+/gimptool-3.0
+/gimptool-3.0.exe
 /test-clipboard
 /test-clipboard.exe
diff --git a/tools/Makefile.am b/tools/Makefile.am
index 7ca1d2c..8f3cea2 100644
--- a/tools/Makefile.am
+++ b/tools/Makefile.am
@@ -13,14 +13,14 @@ SUBDIRS = $(D_pdbgen)
 if OS_WIN32
 
 bin_PROGRAMS = \
-       gimptool-2.0 \
+       gimptool-3.0 \
        gimp-debug-resume
 
 gimp_debug_resume_SOURCES = gimp-debug-resume.c
 
 else
 
-bin_PROGRAMS = gimptool-2.0
+bin_PROGRAMS = gimptool-3.0
 
 endif
 
@@ -29,10 +29,10 @@ noinst_PROGRAMS = test-clipboard
 EXTRA_PROGRAMS = \
        kernelgen
 
-gimptool_2_0_SOURCES = \
+gimptool_3_0_SOURCES = \
        gimptool.c
 
-gimptool_2_0_LDADD = \
+gimptool_3_0_LDADD = \
        $(libgimpbase)                  \
        $(GTK_LIBS)
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgimpbase/gimpenv.c b/libgimpbase/gimpenv.c
index 5d9ac99..96402f9 100644
--- a/libgimpbase/gimpenv.c
+++ b/libgimpbase/gimpenv.c
@@ -159,13 +159,13 @@ gimp_env_init (gboolean plug_in)
  * gimp_directory:
  *
  * Returns the user-specific GIMP settings directory. If the
  * environment variable GIMP2_DIRECTORY exists, it is used. If it is
  * an absolute path, it is used as is.  If it is a relative path, it
  * is taken to be a subdirectory of the home directory. If it is a
  * relative path, and no home directory can be determined, it is taken
  * to be a subdirectory of gimp_data_directory().
  *
  * The usual case is that no GIMP2_DIRECTORY environment variable
  * exists, and then we use the GIMPDIR subdirectory of the local
  * configuration directory:
  *
@@ -198,17 +198,17 @@ gimp_directory (void)
 
   const gchar  *env_gimp_dir;
 
-  env_gimp_dir = g_getenv ("GIMP2_DIRECTORY");
+  env_gimp_dir = g_getenv ("GIMP3_DIRECTORY");
 
   if (gimp_dir)
     {
-      gboolean gimp2_directory_changed = FALSE;
+      gboolean gimp3_directory_changed = FALSE;
 
       /* We have constructed the gimp_dir already. We can return
        * gimp_dir unless some parameter gimp_dir depends on has
        * changed. For now we just check for changes to GIMP2_DIRECTORY
        */
-      gimp2_directory_changed =
+      gimp3_directory_changed =
         (env_gimp_dir == NULL &&
          last_env_gimp_dir != NULL) ||
         (env_gimp_dir != NULL &&
@@ -217,7 +217,7 @@ gimp_directory (void)
          last_env_gimp_dir != NULL &&
          strcmp (env_gimp_dir, last_env_gimp_dir) != 0);
 
-      if (! gimp2_directory_changed)
+      if (! gimp3_directory_changed)
         {
           return gimp_dir;
         }
@@ -229,7 +229,7 @@ gimp_directory (void)
         }
     }
 
   /* Remember the GIMP2_DIRECTORY to next invocation so we can check
    * if it changes
    */
   g_free (last_env_gimp_dir);
@@ -441,7 +441,7 @@ gimp_installation_directory (void)
  * gimp_data_directory:
  *
  * Returns the top directory for GIMP data. If the environment
  * variable GIMP2_DATADIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -465,7 +465,7 @@ gimp_data_directory (void)
                                      GIMP_DATA_VERSION,
                                      NULL);
 
-      gimp_data_dir = gimp_env_get_dir ("GIMP2_DATADIR", DATADIR, tmp);
+      gimp_data_dir = gimp_env_get_dir ("GIMP3_DATADIR", DATADIR, tmp);
       g_free (tmp);
     }
 
@@ -476,7 +476,7 @@ gimp_data_directory (void)
  * gimp_locale_directory:
  *
  * Returns the top directory for GIMP locale files. If the environment
  * variable GIMP2_LOCALEDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -502,7 +502,7 @@ gimp_locale_directory (void)
                                      "locale",
                                      NULL);
 
-      gimp_locale_dir = gimp_env_get_dir ("GIMP2_LOCALEDIR", LOCALEDIR, tmp);
+      gimp_locale_dir = gimp_env_get_dir ("GIMP3_LOCALEDIR", LOCALEDIR, tmp);
       g_free (tmp);
 
 #ifdef G_OS_WIN32
@@ -519,7 +519,7 @@ gimp_locale_directory (void)
  * gimp_sysconf_directory:
  *
  * Returns the top directory for GIMP config files. If the environment
  * variable GIMP2_SYSCONFDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
  * from the executable's full filename is used.
@@ -543,7 +543,7 @@ gimp_sysconf_directory (void)
                                      GIMP_SYSCONF_VERSION,
                                      NULL);
 
-      gimp_sysconf_dir = gimp_env_get_dir ("GIMP2_SYSCONFDIR", SYSCONFDIR, tmp);
+      gimp_sysconf_dir = gimp_env_get_dir ("GIMP3_SYSCONFDIR", SYSCONFDIR, tmp);
       g_free (tmp);
     }
 
@@ -571,7 +571,7 @@ gimp_user_directory (GimpUserDirectory type)
  * gimp_plug_in_directory:
  *
  * Returns the top directory for GIMP plug_ins and modules. If the
  * environment variable GIMP2_PLUGINDIR exists, that is used.  It
  * should be an absolute pathname. Otherwise, on Unix the compile-time
  * defined directory is used. On Windows, the installation directory as
  * deduced from the executable's full filename is used.
@@ -595,7 +595,7 @@ gimp_plug_in_directory (void)
                                      GIMP_PLUGIN_VERSION,
                                      NULL);
 
-      gimp_plug_in_dir = gimp_env_get_dir ("GIMP2_PLUGINDIR", PLUGINDIR, tmp);
+      gimp_plug_in_dir = gimp_env_get_dir ("GIMP3_PLUGINDIR", PLUGINDIR, tmp);
       g_free (tmp);
     }
 
@@ -159,13 +159,13 @@ gimp_env_init (gboolean plug_in)
  *
  * Returns the user-specific GIMP settings directory. If the
- * environment variable GIMP2_DIRECTORY exists, it is used. If it is
+ * environment variable GIMP3_DIRECTORY exists, it is used. If it is
  * an absolute path, it is used as is.  If it is a relative path, it
  * is taken to be a subdirectory of the home directory. If it is a
@@ -159,13 +159,13 @@ gimp_env_init (gboolean plug_in)
  * to be a subdirectory of gimp_data_directory().
  *
- * The usual case is that no GIMP2_DIRECTORY environment variable
+ * The usual case is that no GIMP3_DIRECTORY environment variable
  * exists, and then we use the GIMPDIR subdirectory of the local
  * configuration directory:
@@ -198,17 +198,17 @@ gimp_directory (void)
       /* We have constructed the gimp_dir already. We can return
        * gimp_dir unless some parameter gimp_dir depends on has
-       * changed. For now we just check for changes to GIMP2_DIRECTORY
+       * changed. For now we just check for changes to GIMP3_DIRECTORY
        */
@@ -229,7 +229,7 @@ gimp_directory (void)
     }
 
-  /* Remember the GIMP2_DIRECTORY to next invocation so we can check
+  /* Remember the GIMP3_DIRECTORY to next invocation so we can check
    * if it changes
    */
@@ -441,7 +441,7 @@ gimp_installation_directory (void)
  *
  * Returns the top directory for GIMP data. If the environment
- * variable GIMP2_DATADIR exists, that is used.  It should be an
+ * variable GIMP3_DATADIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -476,7 +476,7 @@ gimp_data_directory (void)
  *
  * Returns the top directory for GIMP locale files. If the environment
- * variable GIMP2_LOCALEDIR exists, that is used.  It should be an
+ * variable GIMP3_LOCALEDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -519,7 +519,7 @@ gimp_locale_directory (void)
  *
  * Returns the top directory for GIMP config files. If the environment
- * variable GIMP2_SYSCONFDIR exists, that is used.  It should be an
+ * variable GIMP3_SYSCONFDIR exists, that is used.  It should be an
  * absolute pathname.  Otherwise, on Unix the compile-time defined
  * directory is used. On Windows, the installation directory as deduced
@@ -571,7 +571,7 @@ gimp_user_directory (GimpUserDirectory type)
  *
  * Returns the top directory for GIMP plug_ins and modules. If the
- * environment variable GIMP2_PLUGINDIR exists, that is used.  It
+ * environment variable GIMP3_PLUGINDIR exists, that is used.  It
  * should be an absolute pathname. Otherwise, on Unix the compile-time
  * defined directory is used. On Windows, the installation directory as